@@ -39,3 +39,19 @@ def process_datetime_range(start, end, freq=None):
     datetime_end = datetime_index[-1].to_pydatetime()
 
     return datetime_start, datetime_end, datetime_index
+
+
+def parse_influx_result(
+    result: pd.DataFrame, aditional_indices: list[str] = None
+) -> pd.DataFrame:
+    """Parse resulting DataFrame of flux query to a format we expect in the rest of the lib."""
+    indices = ["_time"]
+    if aditional_indices is not None:
+        indices.extend(aditional_indices)
+
+    result["_time"] = pd.to_datetime(result["_time"])
+    result = result.pivot_table(columns="_field", values="_value", index=indices)
+    result = result.reset_index().set_index("_time")
+    result.index.name = "datetime"
+    result.columns.name = ""
+    return result
